@@ -19,6 +19,7 @@ from barbican.api import controllers
 from barbican.api.controllers import acls
 from barbican.api.controllers import consumers
 from barbican.api.controllers import secretmeta
+from barbican.api.controllers import versions
 from barbican.common import accept
 from barbican.common import exception
 from barbican.common import hrefs
@@ -76,17 +77,12 @@ class SecretController(controllers.ACLMixin):
 
     def __init__(self, secret):
         LOG.debug('=== Creating SecretController ===')
+        super().__init__()
         self.secret = secret
-        self.consumers = consumers.SecretConsumersController(secret.id)
+        self.consumers = consumers.SecretConsumersController(secret)
         self.consumer_repo = repo.get_secret_consumer_repository()
         self.transport_key_repo = repo.get_transport_key_repository()
 
-    def get_acl_tuple(self, req, **kwargs):
-        d = self.get_acl_dict_for_user(req, self.secret.secret_acls)
-        d['project_id'] = self.secret.project.external_id
-        d['creator_id'] = self.secret.creator_id
-        return 'secret', d
-
     @pecan.expose()
     def _lookup(self, sub_resource, *remainder):
         if sub_resource == 'acl':
@@ -123,6 +119,9 @@ class SecretController(controllers.ACLMixin):
 
             LOG.info('Retrieved secret metadata for project: %s',
                      external_project_id)
+            if versions.is_supported(pecan.request, max_version='1.0'):
+                # NOTE(xek): consumers are being introduced in 1.1
+                del resp['consumers']
             return resp
         else:
             LOG.warning('Decrypted secret %s requested using deprecated '
@@ -260,6 +259,12 @@ class SecretController(controllers.ACLMixin):
             self.secret.id,
             suppress_exception=True
         )
+
+        # With ACL support, the user token project does not have to be same as
+        # project associated with secret. The lookup project_id needs to be
+        # derived from the secret's data considering authorization is already
+        # done.
+        external_project_id = self.secret.project.external_id
         plugin.delete_secret(self.secret, external_project_id)
         LOG.info('Deleted secret for project: %s', external_project_id)
 
@@ -276,6 +281,7 @@ class SecretsController(controllers.ACLMixin):
 
     def __init__(self):
         LOG.debug('Creating SecretsController')
+        super().__init__()
         self.validator = validators.NewSecretValidator()
         self.secret_repo = repo.get_secret_repository()
         self.quota_enforcer = quota.QuotaEnforcer('secrets', self.secret_repo)
@@ -358,8 +364,14 @@ class SecretsController(controllers.ACLMixin):
     @controllers.handle_exceptions(u._('Secret(s) retrieval'))
     @controllers.enforce_rbac('secrets:get')
     def on_get(self, external_project_id, **kw):
+        no_consumers = versions.is_supported(pecan.request, max_version='1.0')
+        # NOTE(xek): consumers are being introduced in 1.1
+
         def secret_fields(field):
-            return putil.mime_types.augment_fields_with_content_types(field)
+            resp = putil.mime_types.augment_fields_with_content_types(field)
+            if no_consumers:
+                del resp['consumers']
+            return resp
 
         LOG.debug('Start secrets on_get '
                   'for project-ID %s:', external_project_id)
