@@ -316,6 +316,11 @@ class Secret(BASE, SoftDeleteMixIn, ModelBase):
         backref="secret",
         cascade="all, delete-orphan")
 
+    consumers = orm.relationship(
+        "SecretConsumerMetadatum",
+        backref="secret",
+        cascade="all, delete-orphan")
+
     def __init__(self, parsed_request=None, check_exc=True):
         """Creates secret from a dict."""
         super(Secret, self).__init__()
@@ -348,10 +353,10 @@ class Secret(BASE, SoftDeleteMixIn, ModelBase):
             datum.delete(session)
 
         for secret_ref in self.container_secrets:
-            session.delete(secret_ref)
+            secret_ref.delete(session)
 
         for secret_acl in self.secret_acls:
-            session.delete(secret_acl)
+            secret_acl.delete(session)
 
     def _do_extra_dict_fields(self):
         """Sub-class hook method: return dict of fields."""
@@ -369,6 +374,13 @@ class Secret(BASE, SoftDeleteMixIn, ModelBase):
             'bit_length': self.bit_length,
             'mode': self.mode,
             'creator_id': self.creator_id,
+            "consumers": [
+                {
+                    "service": consumer.service,
+                    "resource_type": consumer.resource_type,
+                    "resource_id": consumer.resource_id,
+                } for consumer in self.consumers if not consumer.deleted
+            ],
         }
 
 
@@ -571,16 +583,16 @@ class Order(BASE, SoftDeleteMixIn, ModelBase):
         cascade="all, delete-orphan")
 
     def __init__(self, parsed_request=None, check_exc=True):
-            """Creates a Order entity from a dict."""
-            super(Order, self).__init__()
-            if parsed_request:
-                self.type = parsed_request.get('type')
-                self.meta = parsed_request.get('meta')
-                self.status = States.ACTIVE
-                self.sub_status = parsed_request.get('sub_status')
-                self.sub_status_message = parsed_request.get(
-                    'sub_status_message')
-                self.creator_id = parsed_request.get('creator_id')
+        """Creates a Order entity from a dict."""
+        super(Order, self).__init__()
+        if parsed_request:
+            self.type = parsed_request.get('type')
+            self.meta = parsed_request.get('meta')
+            self.status = States.ACTIVE
+            self.sub_status = parsed_request.get('sub_status')
+            self.sub_status_message = parsed_request.get(
+                'sub_status_message')
+            self.creator_id = parsed_request.get('creator_id')
 
     def set_error_reason_safely(self, error_reason_raw):
         """Ensure error reason does not raise database attribute exceptions."""
@@ -1493,3 +1505,64 @@ class ProjectSecretStore(BASE, ModelBase):
         """Sub-class hook method: return dict of fields."""
         return {'secret_store_id': self.secret_store_id,
                 'project_id': self.project_id}
+
+
+class SecretConsumerMetadatum(BASE, SoftDeleteMixIn, ModelBase):
+    """Stores Consumer Registrations for Secrets in the datastore.
+
+    Services can register interest in Secrets. Services will provide a
+    resource type and a resource id for the object that is using the Secret.
+    """
+
+    __tablename__ = "secret_consumer_metadata"
+
+    secret_id = sa.Column(
+        sa.String(36), sa.ForeignKey("secrets.id"), index=True, nullable=False
+    )
+    project_id = sa.Column(
+        sa.String(36), sa.ForeignKey("projects.id"), index=True, nullable=True
+    )
+    service = sa.Column(sa.String(255), nullable=False)
+    resource_type = sa.Column(sa.String(255), nullable=False)
+    resource_id = sa.Column(sa.String(36), index=True, nullable=False)
+
+    __table_args__ = (
+        sa.UniqueConstraint(
+            "secret_id", "service", "resource_type", "resource_id",
+            name="_secret_consumer_resource_uc"
+        ),
+    )
+
+    def __init__(self, secret_id=None, project_id=None, service=None,
+                 resource_type=None, resource_id=None, check_exc=True):
+        """Registers a Consumer to a Secret."""
+        super(SecretConsumerMetadatum, self).__init__()
+
+        msg = u._("Must supply non-None {0} argument "
+                  "for SecretConsumerMetadatum entry.")
+
+        if secret_id is None and check_exc:
+            raise exception.MissingArgumentError(msg.format("secret_id"))
+        if project_id is None and check_exc:
+            raise exception.MissingArgumentError(msg.format("project_id"))
+        if service is None and check_exc:
+            raise exception.MissingArgumentError(msg.format("service"))
+        if resource_type is None and check_exc:
+            raise exception.MissingArgumentError(msg.format("resource_type"))
+        if resource_id is None and check_exc:
+            raise exception.MissingArgumentError(msg.format("resource_id"))
+
+        self.secret_id = secret_id
+        self.project_id = project_id
+        self.service = service
+        self.resource_type = resource_type
+        self.resource_id = resource_id
+        self.status = States.ACTIVE
+
+    def _do_extra_dict_fields(self):
+        """Sub-class hook method: return dict of fields."""
+        return {
+            "service": self.service,
+            "resource_type": self.resource_type,
+            "resource_id": self.resource_id,
+        }
