@@ -19,37 +19,36 @@ import os
 from os import path
 import time
 import types
+from unittest import mock
 
-import mock
+from OpenSSL import crypto
 from oslo_config import cfg
 from oslo_utils import uuidutils
 import oslotest.base as oslotest
 from oslotest import createfile
-
 import six
 from six.moves.urllib import parse
 import webtest
 
-from OpenSSL import crypto
-
 from barbican.api import app
 from barbican.common import config
 import barbican.context
 from barbican.model import repositories
 from barbican.plugin.crypto import manager as cm
 from barbican.plugin.crypto import p11_crypto
-
 from barbican.plugin.interface import secret_store
 from barbican.plugin import kmip_secret_store as kss
 from barbican.tests import database_utils
 
 
-def mock_pecan_request(test_instance, host=None):
+def mock_pecan_request(test_instance, host=None, version='1.0'):
     patcher_obj = mock.patch('pecan.request')
     mock_req = patcher_obj.start()
     test_instance.addCleanup(patcher_obj.stop)
     mock_req.url = host
     mock_req.environ = os.environ.copy()
+    mock_req.environ['key-manager.microversion'] = version
+    mock_req.application_url = host
 
 
 @contextmanager
@@ -140,6 +139,20 @@ class MockModelRepositoryMixin(object):
             mock_repo_obj=mock_container_consumer_repo,
             patcher_obj=self.mock_container_consumer_repo_patcher)
 
+    def setup_secret_consumer_repository_mock(
+            self, mock_secret_consumer_repo=mock.MagicMock()):
+        """Mocks the secret consumer repository factory function
+
+        :param mock_secret_consumer_repo: The pre-configured mock
+                                          secret consumer repo to be
+                                          returned.
+        """
+        self.mock_secret_consumer_repo_patcher = None
+        self._setup_repository_mock(
+            repo_factory='get_secret_consumer_repository',
+            mock_repo_obj=mock_secret_consumer_repo,
+            patcher_obj=self.mock_secret_consumer_repo_patcher)
+
     def setup_container_repository_mock(self,
                                         mock_container_repo=mock.MagicMock()):
         """Mocks the container repository factory function
@@ -672,3 +685,8 @@ def is_pkcs11_enabled():
 
 class DummyClassForTesting(object):
     pass
+
+
+def set_version(app, version):
+    """Sets the requested version in the environ"""
+    app.extra_environ['key-manager.microversion'] = version
