@@ -1,7 +1,14 @@
 # Configure the needed tempest options
 function configure_barbican_tempest() {
     iniset $TEMPEST_CONFIG service_available barbican True
-    iniset $TEMPEST_CONFIG auth tempest_roles creator
+    roles="$(iniget $TEMPEST_CONFIG auth tempest_roles)"
+    if [[ -z $roles ]]; then
+        roles="creator"
+    else
+        roles="$roles,creator"
+    fi
+    iniset $TEMPEST_CONFIG auth tempest_roles $roles
+    iniset $TEMPEST_CONFIG service_available barbican True
 }
 
 # check for service enabled
@@ -13,7 +20,7 @@ if is_service_enabled barbican; then
 
     if [[ "$1" == "stack" && "$2" == "install" ]]; then
         echo_summary "Installing Barbican"
-        install_barbican
+        stack_install_service barbican
         install_barbicanclient
         if is_service_enabled barbican-pykmip; then
             echo_summary "Installing PyKMIP"
@@ -42,7 +49,6 @@ if is_service_enabled barbican; then
             echo_summary "Configuring Vault plugin"
             configure_vault_plugin
         fi
-        configure_barbicanclient
 
         # Configure Cinder, Nova and Glance to use Barbican
         configure_core_services
